openfaas-lambda-utils
========================
Python Library containing utility functions for use in OpenFaaS lambda implementations

## Installation

Installation:
```bash
   sudo python setup.py install
```
